@@ -34,6 +34,7 @@
 #include "xdgicon.h"
 #include "application_interface.h" // generated interface for DBus org.freedesktop.Application
 #include "xdgmimeapps.h"
+#include "xdgdefaultapps.h"
 
 #include <cstdlib>
 #include <unistd.h>
@@ -87,7 +88,6 @@ static const QLatin1String urlKey("URL");
 static const QLatin1String iconKey("Icon");
 
 // Helper functions prototypes
-bool checkTryExec(const QString& progName);
 QString &doEscape(QString& str, const QHash<QChar,QChar> &repl);
 QString &doUnEscape(QString& str, const QHash<QChar,QChar> &repl);
 QString &escape(QString& str);
@@ -459,21 +459,37 @@ bool XdgDesktopFileData::startApplicationDetached(const XdgDesktopFile *q, const
         if (startByDBus(action, urls))
             return true;
     }
-    QStringList args = action.isEmpty()
+    QStringList args;
+    QStringList appArgs = action.isEmpty()
         ? q->expandExecString(urls)
         : XdgDesktopAction{*q, action}.expandExecString(urls);
 
-    if (args.isEmpty())
+    if (appArgs.isEmpty())
         return false;
 
     if (q->value(QLatin1String("Terminal")).toBool())
     {
-        QString term = QString::fromLocal8Bit(qgetenv("TERM"));
-        if (term.isEmpty())
-            term = QLatin1String("xterm");
+        XdgDesktopFile *terminal = XdgDefaultApps::terminal();
+        QString terminalCommand;
+        if (terminal != nullptr && terminal->isValid())
+        {
+            terminalCommand = terminal->value(execKey).toString();
+        }
+        else
+        {
+            qWarning() << "XdgDesktopFileData::startApplicationDetached(): Using fallback terminal (xterm).";
+            terminalCommand = QStringLiteral("xterm");
+        }
 
-        args.prepend(QLatin1String("-e"));
-        args.prepend(term);
+        delete terminal;
+
+        args.append(QProcess::splitCommand(terminalCommand));
+        args.append(QLatin1String("-e"));
+        args.append(appArgs);
+    }
+    else
+    {
+        args = appArgs;
     }
 
     bool detach = StartDetachTruly::instance();
@@ -613,11 +629,7 @@ QStringList XdgDesktopFileData::getListValue(const XdgDesktopFile * q, const QSt
         if (!q->contains(used_key))
             return QStringList();
     }
-#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
     return q->value(used_key).toString().split(QLatin1Char(';'), Qt::SkipEmptyParts);
-#else
-    return q->value(used_key).toString().split(QLatin1Char(';'), QString::SkipEmptyParts);
-#endif
 }
 
 
@@ -710,18 +722,10 @@ bool XdgDesktopFile::save(QIODevice *device) const
         if (sect != section)
         {
             section = sect;
-#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
             stream << QLatin1Char('[') << section << QLatin1Char(']') << Qt::endl;
-#else
-            stream << QLatin1Char('[') << section << QLatin1Char(']') << endl;
-#endif
         }
         QString key = path.section(QLatin1Char('/'), 1);
-#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
         stream << key << QLatin1Char('=') << i.value().toString() << Qt::endl;
-#else
-        stream << key << QLatin1Char('=') << i.value().toString() << endl;
-#endif
         ++i;
     }
     return true;
@@ -934,11 +938,7 @@ QString const XdgDesktopFile::actionIconName(const QString & action) const
 
 QStringList XdgDesktopFile::mimeTypes() const
 {
-#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
     return value(mimeTypeKey).toString().split(QLatin1Char(';'), Qt::SkipEmptyParts);
-#else
-    return value(mimeTypeKey).toString().split(QLatin1Char(';'), QString::SkipEmptyParts);
-#endif
 }
 
 
@@ -1219,23 +1219,6 @@ QStringList XdgDesktopFile::expandExecString(const QStringList& urls) const
 }
 
 
-bool checkTryExec(const QString& progName)
-{
-    if (progName.startsWith(QDir::separator()))
-        return QFileInfo(progName).isExecutable();
-
-    const QStringList dirs = QFile::decodeName(qgetenv("PATH")).split(QLatin1Char(':'));
-
-    for (const QString &dir : dirs)
-    {
-        if (QFileInfo(QDir(dir), progName).isExecutable())
-            return true;
-    }
-
-    return false;
-}
-
-
 QString XdgDesktopFile::id(const QString &fileName, bool checkFileExists)
 {
     const QFileInfo f(fileName);
@@ -1246,9 +1229,9 @@ QString XdgDesktopFile::id(const QString &fileName, bool checkFileExists)
     }
 
     QString id = f.absoluteFilePath();
-    const QStringList dataDirs = XdgDirs::dataDirs();
+    const QStringList dirs = QStringList() << XdgDirs::dataHome() << XdgDirs::dataDirs();
 
-    for (const QString &d : dataDirs) {
+    for (const QString &d : dirs) {
         if (id.startsWith(d)) {
             // remove only the first occurence
             id.replace(id.indexOf(d), d.size(), QString());
@@ -1346,14 +1329,23 @@ bool XdgDesktopFile::isSuitable(bool excludeHidden, const QString &environment)
     }
 
     // actually installed. If not, entry may not show in menus, etc.
-    QString s = value(QLatin1String("TryExec")).toString();
-    if (!s.isEmpty() && ! checkTryExec(s))
-        return false;
+    if (contains(QLatin1String("TryExec")))
+        return tryExec();
 
     return true;
 }
 
 
+bool XdgDesktopFile::tryExec() const
+{
+    const QString progName = value(QLatin1String("TryExec")).toString();
+    if (progName.isEmpty())
+        return false;
+
+    return (QStandardPaths::findExecutable(progName).isEmpty()) ? false : true;
+}
+
+
 QString expandDynamicUrl(QString url)
 {
     const QStringList env = QProcess::systemEnvironment();
@@ -1472,11 +1464,7 @@ bool readDesktopFile(QIODevice & device, QSettings::SettingsMap & map)
 
         if (value.contains(QLatin1Char(';')))
         {
-#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
             map.insert(key, value.split(QLatin1Char(';'), Qt::SkipEmptyParts));
-#else
-            map.insert(key, value.split(QLatin1Char(';'), QString::SkipEmptyParts));
-#endif
         }
         else
         {
