@@ -25,6 +25,7 @@
 #include "defwebbrowsermatcommand.h"
 #include "defemailclientmatcommand.h"
 #include "deffilemanagermatcommand.h"
+#include "defterminalmatcommand.h"
 
 #include "xdgmacros.h"
 
@@ -88,6 +89,9 @@ int main(int argc, char *argv[])
     MatCommandInterface *const defFileManagerCmd = new DefFileManagerMatCommand(&parser);
     manager->add(defFileManagerCmd);
 
+    MatCommandInterface *const defTerminalCmd = new DefTerminalMatCommand(&parser);
+    manager->add(defTerminalCmd);
+
     // Find out the positional arguments.
     parser.parse(QCoreApplication::arguments());
     const QStringList args = parser.positionalArguments();
